TokenKind

Enum TokenKind 

pub enum TokenKind {
Show 94 variants Identifier(Identifier), Integer((BigUint, LiteralKind)), HexInteger((BigUint, LiteralKind)), BinInteger((BigUint, LiteralKind)), True, False, Low, High, HighImp, Reg, Let, Decl, Instance, Reset, Initial, If, Else, Match, Set, Pipeline, Stage, Entity, Trait, Impl, For, Function, Enum, Struct, Port, Mod, Use, As, Assert, Mut, Inv, Pub, Where, Gen, Extern, Unsafe, Plus, Minus, Asterisk, Slash, Percentage, Equals, NotEquals, Lt, Gt, Le, Ge, ArithmeticRightShift, RightShift, LeftShift, DoublePipe, LogicalAnd, LogicalXor, Ampersand, Pipe, Not, BitwiseXor, Tilde, InfixOperatorSeparator, Assignment, OpenParen, CloseParen, OpenBrace, CloseBrace, OpenBracket, CloseBracket, FatArrow, SlimArrow, Comma, Dot, DotDot, Semi, GreekQuestionMark, Colon, PathSeparator, Hash, Dollar, Label(Identifier), LabelRef(Identifier), AsciiCharLiteral(String), AsciiStringLiteral(String), Utf8CharLiteral, String(String), OutsideDocumentation(String), InsideDocumentation(String), Whitespace, Comment, BlockCommentStart, BlockCommentEnd, Eof,
}

Variants



Identifier(Identifier)



Integer((BigUint, LiteralKind))



HexInteger((BigUint, LiteralKind))



BinInteger((BigUint, LiteralKind))



True



False



Low



High



HighImp



Reg



Let



Decl



Instance



Reset



Initial



If



Else



Match



Set



Pipeline



Stage



Entity



Trait



Impl



For



Function



Enum



Struct



Port



Mod



Use



As



Assert



Mut



Inv



Pub



Where



Gen



Extern



Unsafe



Plus



Minus



Asterisk



Slash



Percentage



Equals



NotEquals



Lt



Gt



Le



Ge



ArithmeticRightShift



RightShift



LeftShift



DoublePipe



LogicalAnd



LogicalXor



Ampersand



Pipe



Not



BitwiseXor



Tilde



InfixOperatorSeparator



Assignment



OpenParen



CloseParen



OpenBrace



CloseBrace



OpenBracket



CloseBracket



FatArrow



SlimArrow



Comma



Dot



DotDot



Semi



GreekQuestionMark



Colon



PathSeparator



Hash



Dollar



Label(Identifier)



LabelRef(Identifier)



AsciiCharLiteral(String)



AsciiStringLiteral(String)



Utf8CharLiteral



String(String)



OutsideDocumentation(String)



InsideDocumentation(String)



Whitespace

Ignoring whitespace



Comment



BlockCommentStart



BlockCommentEnd



Eof

Implementations

Source

impl TokenKind

pub fn as_str(&self) -> &'static str

pub fn is_identifier(&self) -> bool

pub fn is_string(&self) -> bool

pub fn is_integer(&self) -> bool

pub fn as_biguint(&self) -> Option<BigUint>