pub struct NamespacedFile {
pub base_namespace: Path,
pub namespace: Path,
pub file: PathBuf,
}Fields
base_namespace: PathThe namespace which is the root of this file, i.e. what is referred to when when starting a path with lib::
namespace: PathThe namespace of the items added in this file.
file: PathBufTrait Implementations
Sourceimpl Clone for NamespacedFile
impl Clone for NamespacedFile
Sourcefn clone(&self) -> NamespacedFile
fn clone(&self) -> NamespacedFile
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for NamespacedFile
impl Debug for NamespacedFile
Sourceimpl PartialEq for NamespacedFile
impl PartialEq for NamespacedFile
impl Eq for NamespacedFile
impl StructuralPartialEq for NamespacedFile